# -*- coding: utf-8 -*-
from pathlib import Path

import pytest
from PIL import Image

FIXTURES = Path(__file__).resolve().parent / "data"


@pytest.fixture(autouse=True)
def setup_environment(responses):
    arkindex_iiif_server = "https://europe-gamma.iiif.teklia.com/iiif/2"

    # Allow downloading missing images
    responses.add_passthru(arkindex_iiif_server)


@pytest.fixture
def database():
    return FIXTURES / "test_db.sqlite"


@pytest.fixture
def image_large_height():
    return Image.open(FIXTURES / "images" / "big_height.jpg")


@pytest.fixture
def image_small_height():
    return Image.open(FIXTURES / "images" / "small_height.jpg")


@pytest.fixture
def image_cache():
    return FIXTURES / "images"


@pytest.fixture
def fake_expected_partitions():
    partitions_dir = FIXTURES / "pinned_insects/partitions"
    return {
        part_file.name: part_file.read_text().strip().split("\n")
        for part_file in partitions_dir.glob("*.lst")
    }
