# -*- coding: utf-8 -*-


import json

import pytest

from atr_data_generator.arguments import CommonArgs
from atr_data_generator.extract.arguments import (
    MANUAL,
    FilterArgs,
    ImageArgs,
    SelectArgs,
)
from atr_data_generator.extract.base import EXPORT_PATH, DataGenerator
from atr_data_generator.split.arguments import Partition, SplitArgs


@pytest.mark.parametrize(
    "worker_version_ids",
    (
        ([]),
        ([MANUAL]),  # only manual transcriptions
    ),
)
@pytest.mark.parametrize(
    "folders, expected_trans_lines",
    (
        (["a0c4522d-2d80-4766-a01c-b9d686f41f6a"], [17]),
        (
            [
                "a0c4522d-2d80-4766-a01c-b9d686f41f6a",
                "39b9ac5c-89ab-4258-8116-965bf0ca0419",
            ],
            [17, 21],
        ),
    ),
)
def test_run(
    database,
    folders,
    image_cache,
    worker_version_ids,
    expected_trans_lines,
    tmp_path,
):
    train_folder, val_folder = folders if len(folders) == 2 else (folders[0], None)
    atr_data_gen = DataGenerator(
        common=CommonArgs(
            dataset_name="test", output_dir=tmp_path, cache_dir=image_cache
        ),
        image=ImageArgs(),
        select=SelectArgs(),
        filter=FilterArgs(accepted_worker_version_ids=worker_version_ids),
        split=SplitArgs(train_folder=train_folder, validation_folder=val_folder),
    )

    atr_data_gen.run(database)

    # Read json transcription file
    data = json.loads((atr_data_gen.common.output_dir / EXPORT_PATH).read_text())

    for partition, count in zip(Partition, expected_trans_lines):
        assert len(data[partition.value]) == count

    # each image file should have one transcription file
    img_files = list(atr_data_gen.common.output_dir.rglob("*.jpg"))
    assert len(img_files) == sum(expected_trans_lines)
