# -*- coding: utf-8 -*-

import pytest
import pytest_lazyfixture
from document_processing.utils import BoundingBox

from atr_data_generator.extract.utils import _is_vertical, resize_image_height


@pytest.mark.parametrize(
    "bbox, vertical",
    (
        (BoundingBox(x=0, y=0, height=100, width=1000), False),
        (BoundingBox(x=0, y=0, height=1000, width=100), True),
    ),
)
def test_is_vertical(bbox, vertical):
    assert _is_vertical(bbox) is vertical


@pytest.mark.parametrize("height", (128, 200))
@pytest.mark.parametrize(
    "image",
    (
        pytest_lazyfixture.lazy_fixture("image_large_height"),
        pytest_lazyfixture.lazy_fixture("image_small_height"),
    ),
)
def test_resized_image_fixed_height(height, image):
    assert resize_image_height(image, height).height == height
