# -*- coding: utf-8 -*-

import random

from atr_data_generator.arguments import CommonArgs
from atr_data_generator.split.arguments import SplitArgs
from atr_data_generator.split.main import PartitionSplitter


def test_create_partitions(fake_expected_partitions, tmp_path):
    splitter = PartitionSplitter(
        common=CommonArgs(dataset_name="test", output_dir=tmp_path), split=SplitArgs()
    )

    all_ids = []
    for split_name, expected_split_ids in fake_expected_partitions.items():
        all_ids += expected_split_ids

    # shuffle to show that splits are reproducible
    random.shuffle(all_ids)

    # just to check that there's no problem with the data
    assert len(all_ids) > 0

    partitions_dir = splitter.output_dir / "Partitions"
    lines_dir = splitter.output_dir / "Lines"
    trans_dir = splitter.output_dir / "Transcriptions"

    # create fake data
    for line_id in all_ids:
        trans_file = trans_dir / f"{line_id}.txt"
        trans_file.parent.mkdir(parents=True, exist_ok=True)
        trans_file.touch()

        img_file = lines_dir / f"{line_id}.jpg"
        img_file.parent.mkdir(parents=True, exist_ok=True)
        img_file.touch()

    splitter.create_partitions()

    for split_name, expected_split_ids in fake_expected_partitions.items():
        part_file = partitions_dir / split_name
        assert part_file.read_text().strip().split("\n") == expected_split_ids
